<template>
  <div class="export">
    <span type="primary" plain @click="openDialog" icon="el-icon-upload2"
      >导入</span
    >
    <el-dialog
      :visible="dialogImportVisible"
      :title="importData.title"
      width="500px"
      :before-close="cancelConfirm"
      destroy-on-close
      :modal="false"
      :close-on-click-modal="false"
    >
      <el-form ref="form" label-width="150px">
        <ht-form-item label="默认模板">
          <a class="download-btn" @click="downLoadTemplete">
            <!-- :download="importData.templateName"
            :href="importData.downloadUrl" -->
            <i class="el-icon-download"></i>
            模板下载
          </a>
        </ht-form-item>
        <ht-form-item label="文件导入">
          <el-upload
            style="display: inline-block"
            :action="importData.importUrl"
            :on-success="hadleUploadResult"
            :on-error="hadleUploadResult"
            :headers="uploadHeaders"
            :on-exceed="onExceed"
            accept=".xlsx,.xls"
            :before-upload="beforeUpload"
            :limit="1"
            :data="importDataParams"
            :auto-upload="false"
            ref="upload"
          >
            <el-button type="primary" icon="el-icon-upload" plain
              >选择Excel文件</el-button
            >
          </el-upload>
        </ht-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button
          type="primary"
          @click="submitImport"
          element-loading-text="拼命导入中"
          v-loading.fullscreen.lock="fullscreenLoading"
          >确 定</el-button
        >
        <el-button @click="cancelConfirm()">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import req from '@/request.js'
const portal = window.context.portal
export default {
  name: 'importFile',
  props: {
    importData: {
      type: Object,
      default: function () {
        return []
      },
    },
  },
  data() {
    return {
      importDataParams: {},
      dialogImportVisible: false,
      fullscreenLoading: false,
    }
  },
  computed: {
    uploadHeaders: function () {
      return {
        Authorization: 'Bearer ' + this.$store.state.login.currentUser.token,
      }
    },
  },
  methods: {
    downLoadTemplete() {
      this.loading = true
      req
        .downloadGet(`${portal}/yhxt/api/file/download?fileType=2`)
        .then((res) => {
          this.loading = false
          const blob = new Blob([res.data], {
            type: 'application/vnd.ms-excel',
          })
          let link = document.createElement('a') //定义一个a标签
          link.href = window.URL.createObjectURL(blob) //需要生成一个 URL 来实现下载，链接到blob上
          link.download = this.importData.templateName //下载后的文件名称
          link.click() //模拟在按钮上实现一次鼠标点击
          window.URL.revokeObjectURL(link.href) //释放 URL 对象
        })
        .catch(() => {
          this.loading = false
        })
    },
    openDialog() {
      if (this.importData.mqiId !== '') {
        this.dialogImportVisible = true
        if (this.importData.mqiId == false) {
          this.dialogImportVisible = true
        }
        // else {
        this.importDataParams.mqiId = this.importData.mqiId
        let obj = this.importData.params
        if (obj) {
          for (let i in obj) {
            this.importDataParams[i] = obj[i]
          }
        }
        // }
      } else {
        this.$message.warning('请先选择一条项目进行导入')
      }
    },
    cancelConfirm() {
      this.$refs.upload.clearFiles()
      this.dialogImportVisible = false
      this.$refs.upload.uploadFiles = []
    },
    submitImport() {
      if (
        !this.$refs.upload.uploadFiles ||
        this.$refs.upload.uploadFiles.length == 0
      ) {
        this.$message.warning('请选择要导入的数据文件!')
        return false
      }
      this.$refs.upload.submit()
    },
    hadleUploadResult(response) {
      this.fullscreenLoading = false
      if (response.state) {
        this.$message.success(response.message)
        this.dialogImportVisible = false
        // this.$parent.$refs.AtTable.load()
        this.$emit('load', response.value)
      } else {
        this.$message.error(response.message)
      }
    },
    onExceed() {
      this.$message.warning('只能选择一个Excel文件!')
    },
    beforeUpload(file) {
      this.fileInfo = file
      if (!file.name.endsWith('.xlsx') && !file.name.endsWith('.xls')) {
        this.$message.warning('只能导入Excel文件!')
        return false
      }
      this.fullscreenLoading = true
    },
  },
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';
.download-btn {
  color: #fff !important;
  background-color: $--color-primary;
  border-color: $--color-primary;
  padding: 10px 15px;
  font-size: 12px;
  border-radius: 4px;
  cursor: pointer;
  text-decoration: none;
}
/deep/.el-form-item--small .el-form-item__content {
  text-align: initial;
}
.export {
  margin-left: 10px;
}
</style>
